import os
import sys
from autoenv_tool.utils.env import read_env, create_env, create_env_file, create_utils_folder, create_env_py


def autoenv():
    """ Terminaldan `autoenv` deb yozilganda ishga tushadi """
    env_file = ".env"

    # .env faylini tekshirish va yaratish
    if not os.path.exists(env_file):
        ans = input(".env fayli mavjud emas. Yaratilsinmi? (y/n): ").strip().lower()
        if ans == "y":
            create_env(env_file)
        else:
            print("Amal bekor qilindi.")
            sys.exit(0)

    env_data = read_env(env_file)
    
    print("\n🔹 .env dagi o‘zgaruvchilar:")
    for key, value in env_data.items():
        print(f"{key} = {value}")

    confirm = input("\n♻️  Ushbu o‘zgaruvchilarni yuklashni istaysizmi? (y/n): ").strip().lower()
    if confirm == "y" or confirm == "": 
        for key, value in env_data.items():
            os.environ[key] = value
        print("✅ O‘zgaruvchilar yuklandi!")
    else:
        print("❌ Yuklash bekor qilindi.")


def create():
    """ `autoenv` paketini o'rnatish uchun yordamchi funksiya """
    # `.env` fayli yaratish, `utils` papkasini yaratish va `env.py` faylini yaratish
    create_env_file()
    create_utils_folder()
    create_env_py()
    print("Autoenv setup muvaffaqiyatli yakunlandi!")


if __name__ == "__main__":
    if len(sys.argv) > 1 and sys.argv[1] == "create":
        create()
    else:
        autoenv()



# tests/test_autoenv.py
import os
import pytest
from autoenv_tool.utils.env import read_env, create_env


@pytest.fixture
def env_file(tmpdir):
    """ Temporary .env faylini yaratish uchun fixture """
    env_path = tmpdir.join(".env")
    env_path.write("BOT_TOKEN=my_token_value")
    return env_path


def test_read_env(env_file):
    """ .env faylini to'g'ri o'qish """
    env_data = read_env(str(env_file))
    assert env_data == {"BOT_TOKEN": "my_token_value"}


def test_create_env(tmpdir):
    """ .env faylini yaratish """
    env_path = tmpdir.join(".env")
    create_env(str(env_path))
    assert os.path.exists(str(env_path))
    with open(str(env_path), "r") as f:
        content = f.read()
    assert content == "# .env fayli\n"



from setuptools import setup, find_packages

setup(
    name="autoenv-tool",
    version="0.3",
    packages=find_packages(),
    install_requires=[
        'requests',
        'environs',
    ],
    entry_points={
        'console_scripts': [
            'autoenv=autoenv_tool.cli:autoenv',  # Komanda nomi 'autoenv'
        ],
    },

    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/Husanjonazamov/autoenv-tool',
    author='Husanjon Azamov',
    author_email='azamovhusanboy@gmail.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)



# autoenv/utils/env.py
import os


def read_env(env_file):
    """ .env faylidan o'zgaruvchilarni o'qish """
    env_data = {}
    with open(env_file, "r") as f:
        lines = f.readlines()
        for line in lines:
            if '=' in line:
                key, value = line.strip().split('=', 1)
                env_data[key] = value
    return env_data


def create_env(env_file):
    """ .env faylini yaratish """
    with open(env_file, "w") as f:
        f.write("# .env fayli\n")
    print(f"{env_file} yaratildi!")
    
    
    

def create_env_file():
    # Bosh papkani tekshirish va .env faylini yaratish
    if not os.path.exists(".env"):
        with open(".env", "w") as f:
            f.write("BOT_TOKEN=dusddufa dsfgasdf7f67d6sfads\n")
            f.write("DATABASE_URL=postgres://user:password@localhost/dbname\n")
            # Boshqa misollar kiritilishi mumkin
        print("`.env` fayli yaratildi!")
    else:
        with open(".env", "r") as f:
            content = f.read()
            if not content.strip():  # Fayl bo'sh bo'lsa
                print("Qizil: `.env` faylini to'ldiring!")
            else:
                print("`.env` faylida ma'lumot mavjud.")

def create_utils_folder():
    if not os.path.exists("utils"):
        os.makedirs("utils")
        print("`utils` papkasi yaratildi.")
        

def create_env_py():
    env_py_path = os.path.join("utils", "env.py")
    if not os.path.exists(env_py_path):
        with open(env_py_path, "w") as f:
            f.write('''from environs import Env

env = Env()
env.read_env()

''')
            
            # .env faylidan barcha kalitlarni o'qib, har birini mos ravishda chaqiradi
            with open(".env", "r") as env_file:
                for line in env_file:
                    if '=' in line:
                        key = line.split('=')[0].strip()
                        f.write(f"{key} = env('{key}')\n")
        print("`env.py` fayli yaratildi.")

def main():
    create_env_file()
    create_utils_folder()
    create_env_py()

if __name__ == "__main__":
    main()

